#ifndef __WAVEFORMDISPLAY_H__
#define __WAVEFORMDISPLAY_H__

#define MAX_CHANNELS 32

#define DIV_HORIZONTAL   10
#define DIV_VERTICAL      8

#define MAX_Y  DIV_VERTICAL/2

#include <wx/glcanvas.h>
//#include <wx/dcclient.h>
#include <wx/dcbuffer.h>

//#include "FTGLFontWrapper.h"


class WaveformDisplay : public wxGLCanvas {

public:
    WaveformDisplay(wxWindow *parent, wxWindowID id, const wxPoint &pos, const wxSize &size, wxString desc = "");
    ~WaveformDisplay();

    int SetBufferSize(int newSize);
    int SetActiveChannels(int newActiveChannels);  // bitmask representing which channels to display
    void SetBuffer(float* newBuffer);
    void SetOffset(int ch, float offset);   // how many boxes up or down the given channel should be rendered
    float GetOffset(int ch) { return Offsets[ch]; }
    float SetScale(float newScale, int ch);         // newScale = how many units are represented by each box, e.g. 2.0 = 2 volts per box

    void SetTimeBase(float time) { timeBase = time; }

    void Render();

    void OnPaint(wxPaintEvent &event);
    void OnSize(wxSizeEvent &event);
    
    void SetUpGL();

    DECLARE_EVENT_TABLE();
private:
    void Draw(wxDC &dc);

    int BufferSize;
    int ActiveChannels;
    float* Buffer;
    
    void RenderBackground();
    void RenderSignal();
    
    float Offsets[MAX_CHANNELS];
    float scalingFactor[MAX_CHANNELS];            // vertical scaling factor for signal drawing.

    float timeBase;

};

#endif
